## RemoteController

!!! todo
    There are a lot of properties to be discovered

!!! caution "Saving"
    This class doesn't support property setters yet

### Event Information

Size: 20

### ::: pyflp.controllers.RemoteController
    selection:
      members:
        - kind
        - insert
        - is_vst_param
        - param
        - slot
